[−][src]Enum async_proxy::clients::socks5::Destination
Represents a destination address of a service, to which a user wants to connect through a socks5 proxy. It is a good solution, but not the fastest, so it will be rewritten in the future in preference to a dispatch mechanism
Variants
Ipv4Addr(Ipv4Addr)Represents an IPv4 address
Represents a domain name
Ipv6Addr(Ipv6Addr)Represents an IPv6 address
Implementations
impl Destination[src]
pub fn len_as_buffer(&self) -> usize[src]
Returns the length in bytes of the destination, represented as a buffer